@@ -4,11 +4,12 @@ tests for experiments and batteries, not for expfactory-python
 
 '''
 from selenium.common.exceptions import WebDriverException, UnexpectedAlertPresentException
-from expfactory.experiment import validate, get_experiments, load_experiment
+from expfactory.experiment import validate, get_experiments, load_experiment, find_changed
 from expfactory.views import generate_experiment_web, tmp_experiment
 from numpy.testing import assert_equal, assert_string_equal
-from selenium.webdriver.common.keys import Keys
 from expfactory.utils import find_directories, get_url
+from selenium.webdriver.common.keys import Keys
+from expfactory.vm import download_repo
 from numpy.random import choice
 from selenium import webdriver
 from threading import Thread
@@ -17,6 +18,7 @@ from time import sleep
 import SocketServer
 import webbrowser
 import requests
+import fnmatch
 import shutil
 import numpy
 import json
@@ -114,22 +116,15 @@ def circle_ci_test(experiment_tags,web_folder,experiment_repo=None,delete=True,p
 
         print "DETECTED CONTINUOUS INTEGRATION ENVIRONMENT..."
 
-        current_build = int(os.environ["CIRCLE_BUILD_NUM"])
-        headers = {'Accept' : 'application/json'}
-        current_build_url = "https://circleci.com/api/v1/project/expfactory/expfactory-experiments/%s" %(current_build)
-        current_build = requests.get(current_build_url, headers=headers).json()
-        branch = current_build["branch"]
-        
-        # Find differences with compare
-        files_changed = os.popen("git diff %s..master --name-only" %branch).readlines()
-        print "Found files changed: %s" %(",".join(files_changed))
-
-        # Get unique, changed folders, filter experiments again
-        changed_experiments = numpy.unique([os.path.dirname(x.strip("\n")) for x in files_changed if os.path.dirname(x.strip("\n")) != ""]).tolist()
+        os.system("mkdir master")
+        master_folder = os.path.abspath(os.path.join(os.getcwd(),"master"))
+        download_repo("experiments",master_folder)
+        changed_experiments = [os.path.split(x)[-1] for x in find_changed(os.getcwd(),master_folder)]    
         changed_experiments = [e for e in experiment_tags if e in changed_experiments]
+        os.system("rmdir -r -f %s" %(master_folder))
         
     if len(changed_experiments) > 0:
-        generate_experiment_web(web_folder,experiment_folder=experiment_repo) 
+        generate_experiment_web(web_folder,experiment_folder=os.path.abspath(experiment_repo)) 
         experiment_robot_web(web_folder,experiment_tags=changed_experiments)
     else:
         print "Skipping experiments %s, no changes detected." %(",".join(experiment_tags))
@@ -229,14 +224,15 @@ def key_lookup(keyid):
             return str(keyid.lower())
     return lookup[keyid]
 
-def experiment_robot_web(experimentweb_base,experiment_tags=None,port=None,pause_time=100):
+def experiment_robot_web(web_folder,experiment_tags=None,port=None,pause_time=100):
     '''experiment_robot_web
     Robot to automatically run and test experiments, to work with an experiment web folder (meaning produced with views.get_experiment_web. This folder has the standard battery structure with experiment pre-generated as html files. A separate function will/should eventually be made for single experiment preview.
+    :param experiment_tags: experimentweb generated folder with generate_experiment_web
     :param experiment_tags: list of experiment folders to test
     :param pause_time: time to wait between tasks, in addition to time specified in jspsych
     :param port: port. Randomly selected if None is selected
     '''
-    experimentweb_base = os.path.abspath(experimentweb_base)
+    experimentweb_base = os.path.abspath(web_folder)
 
     if port == None:
         port = choice(range(8000,9999),1)[0]
@@ -270,11 +266,19 @@ def experiment_robot_web(experimentweb_base,experiment_tags=None,port=None,pause
         count=0
         wait_time=0
         while True:
-            print "Testing block %s of %s" %(count,experiment[0]["exp_id"])
-            wait_time,finished = test_block(browser,experiment,pause_time,wait_time)
-            if finished == True:
-                break
-            count+=1
+            print "Testing command %s of %s" %(count,experiment[0]["exp_id"])
+            try:
+                wait_time,finished = test_block(browser,experiment,pause_time,wait_time)
+                if finished == True:
+                    break
+                count+=1
+            except UnexpectedAlertPresentException:
+                print "Found alert: closing."
+                try:
+                    alert = browser.switch_to_alert()
+                    alert.accept()
+                except:
+                    pass
 
         print "FINISHING TEST OF EXPERIMENT %s" %(experiment[0]["exp_id"])
 
@@ -341,7 +345,10 @@ def test_block(browser,experiment,pause_time=0,wait_time=0):
     elif "button_class" in block:
         try:
             buttons = browser.find_elements_by_class_name('%s' %block["button_class"])
-            choice(buttons,1)[0].click()
+            button = choice(buttons,1)[0]
+            if button.is_enabled() == False:
+                browser.execute_script('document.getElementsByClassName("%s")[0].disabled = false' %block["button_class"])
+            browser.execute_script('$(".%s").click()' %block["button_class"])
             sleep(0.5)
         except WebDriverException as e:
             pass
@@ -360,7 +367,9 @@ def test_block(browser,experiment,pause_time=0,wait_time=0):
                 browser.find_element_by_tag_name('html').send_keys(continue_key)
             except ValueError:
                 print "ValueError, %s found as choices." %(choices)
-        elif "type" in block:
+        else:
+                browser.find_element_by_tag_name('html').send_keys(Keys.ENTER)
+        if "type" in block:
             if "type" == "writing":
                 browser.execute_script("document.querySelector('#jspsych-writing-box').text = 'beep boop';")
 
@@ -435,6 +444,7 @@ def get_page(browser,url):
 def run_javascript(browser,code):
     return browser.execute_script(code)
 
+
 def test_experiment(folder=None,battery_folder=None,port=None,pause_time=2000):
     '''test_experiment
     test an experiment locally with the --test tag and the expfactory robot
